@@ -59,7 +59,17 @@ jetColors <- function(N){
 
   ## assemble everything last value is returned
   rgb(temp.rgb[,1], temp.rgb[,2], temp.rgb[,3])
+}
 
+# Stack Overflow
+desat <- function(cols, sat=0.5) {
+    X <- diag(c(1, sat, 1)) %*% rgb2hsv(col2rgb(cols))
+    hsv(X[1,], X[2,], X[3,])
+}
+
+wheel <- function(N, sat = 1) {
+  A <- rev(c("red", "yellow", "green", "cyan", "blue", "magenta"))
+  colorRampPalette(desat(A, sat))(N)
 }
 
 ################################################################
